==> 1.2.2.tar.gz: lib/src/application/application.dart <==
import 'dart:async';

import 'package:flutter/cupertino.dart';
import 'package:flutter/foundation.dart';
import 'package:flutter/material.dart';
import 'package:flutter/scheduler.dart';
import 'package:flutter/services.dart';
import 'package:flutter_localizations/flutter_localizations.dart';
import 'package:flutterx_application/src/localization/labels.dart';
import 'package:flutterx_application/src/routing/app_route.dart';
import 'package:flutterx_application/src/routing/webutils/webutils.dart'
    if (dart.library.html) 'package:flutterx_application/src/routing/webutils/webutils_html.dart';
import 'package:flutterx_live_data/flutterx_live_data.dart';
import 'package:flutterx_preferences/flutterx_preferences.dart';
import 'package:flutterx_utils/flutterx_utils.dart';

part 'application_binding.dart';
part 'application_impl.dart';
part 'view_model.dart';

/// Run application
///
/// This should be the application entrypoint
/// [name] of the application, cannot use a label here
/// [initialize] here you can initialize your dependencies and do initialization task and return the first route
/// [routes] a set of all routes of this app
/// [onUnknownRoute] called when push event is called by the system navigator but the route cannot be resolved
/// [labels] translations supported by the app
/// [onLabel] set labels corresponding to current locale
/// [appFactory] generate app widget
Future<void> runApplication({
  required String name,
  InitializeApp? initialize,
  bool pathUrlStrategy = true,
  required Set<ActivityRoute> routes,
  OnUnknownRoute onUnknownRoute = _defaultOnUnknownRoute,
  Set<LabelInterface>? labels,
  ValueSetter<LabelInterface>? onLabel,
  AppFactory appFactory = _defaultAppFactory,
}) async {
  if (pathUrlStrategy) setPathUrlStrategy();
  WidgetsFlutterBinding.ensureInitialized();
  await Preferences.initialize();
  final initialRoute = initialize == null ? routes.first : await initialize();
  runApp(Application._(
      name: name,
      initialRoute: initialRoute.location,
      routes: routes,
      onUnknownRoute: onUnknownRoute,
      labels: labels,
      onLabel: onLabel,
      appFactory: appFactory));
}

/// Initialize application and return fist route
/// Errors here are unhandled
typedef InitializeApp = FutureOr<ActivityRoute> Function();

/// Called when route cannot be resolved.
///
/// Args passed to this route: location: String
/// When returns null the current route will not change
typedef OnUnknownRoute = ActivityRoute? Function(RouteInformation request);

ActivityRoute? _defaultOnUnknownRoute(RouteInformation request) => null;

/// The returned widget must be or contains in its tree WidgetsApp
/// Use [MaterialApp.router] or [CupertinoApp.router] constructor and pass to it each of the provided parameters
typedef AppFactory = Widget Function(
  GlobalKey key,
  AppRouteInformationProvider routeInformationProvider,
  AppRouteInformationParser routeInformationParser,
  AppRouterDelegate routerDelegate,
  GenerateAppTitle onGenerateTitle,
  Locale? locale,
  Iterable<LocalizationsDelegate> localizationsDelegates,
  Iterable<Locale> supportedLocales,
);

Widget _defaultAppFactory(
  GlobalKey key,
  AppRouteInformationProvider routeInformationProvider,
  AppRouteInformationParser routeInformationParser,
  AppRouterDelegate routerDelegate,
  GenerateAppTitle onGenerateTitle,
  Locale? locale,
  Iterable<LocalizationsDelegate> localizationsDelegates,
  Iterable<Locale> supportedLocales,
) =>
    MaterialApp.router(
        key: key,
        routeInformationProvider: routeInformationProvider,
        routeInformationParser: routeInformationParser,
        routerDelegate: routerDelegate,
        onGenerateTitle: onGenerateTitle,
        locale: locale,
        localizationsDelegates: localizationsDelegates,
        supportedLocales: supportedLocales,
        debugShowCheckedModeBanner: false);

/// Factory for [SystemUiOverlayStyle] used by routes to define overlay style per page
typedef SystemUiStyleBuilder = SystemUiOverlayStyle Function(BuildContext context);

/// Default overlay style from appBarTheme and scaffoldBackgroundColor
SystemUiOverlayStyle defaultSystemUiStyle(BuildContext context) {
  final theme = Theme.of(context);
  final appBarTheme = theme.appBarTheme;
  final statusBarBrightness = appBarTheme.systemOverlayStyle?.statusBarBrightness ??
      appBarTheme.backgroundColor?.brightness ??
      theme.primaryColor.brightness;
  final navBarColor = theme.scaffoldBackgroundColor.darken(.05);
  return SystemUiOverlayStyle(
      systemNavigationBarColor: navBarColor,
      systemNavigationBarIconBrightness: navBarColor.brightness.negative,
      statusBarColor: Colors.black26,
      statusBarBrightness: statusBarBrightness,
      statusBarIconBrightness: appBarTheme.systemOverlayStyle?.statusBarIconBrightness ?? statusBarBrightness.negative);
}

==> 1.2.3.tar.gz: lib/src/application/application.dart <==
import 'dart:async';

import 'package:flutter/cupertino.dart';
import 'package:flutter/foundation.dart';
import 'package:flutter/material.dart';
import 'package:flutter/scheduler.dart';
import 'package:flutter/services.dart';
import 'package:flutter_localizations/flutter_localizations.dart';
import 'package:flutter_web_plugins/url_strategy.dart';
import 'package:flutterx_application/src/localization/labels.dart';
import 'package:flutterx_application/src/routing/app_route.dart';
import 'package:flutterx_live_data/flutterx_live_data.dart';
import 'package:flutterx_preferences/flutterx_preferences.dart';
import 'package:flutterx_utils/flutterx_utils.dart';

part 'application_binding.dart';
part 'application_impl.dart';
part 'view_model.dart';

/// Run application
///
/// This should be the application entrypoint
/// [name] of the application, cannot use a label here
/// [initialize] here you can initialize your dependencies and do initialization task and return the first route
/// [routes] a set of all routes of this app
/// [onUnknownRoute] called when push event is called by the system navigator but the route cannot be resolved
/// [labels] translations supported by the app
/// [onLabel] set labels corresponding to current locale
/// [appFactory] generate app widget
Future<void> runApplication({
  required String name,
  InitializeApp? initialize,
  UrlStrategy? urlStrategy,
  required Set<ActivityRoute> routes,
  OnUnknownRoute onUnknownRoute = _defaultOnUnknownRoute,
  Set<LabelInterface>? labels,
  ValueSetter<LabelInterface>? onLabel,
  AppFactory appFactory = _defaultAppFactory,
}) async {
  setUrlStrategy(urlStrategy ?? PathUrlStrategy());
  WidgetsFlutterBinding.ensureInitialized();
  await Preferences.initialize();
  final initialRoute = initialize == null ? routes.first : await initialize();
  runApp(Application._(
      name: name,
      initialRoute: initialRoute.location,
      routes: routes,
      onUnknownRoute: onUnknownRoute,
      labels: labels,
      onLabel: onLabel,
      appFactory: appFactory));
}

/// Initialize application and return fist route
/// Errors here are unhandled
typedef InitializeApp = FutureOr<ActivityRoute> Function();

/// Called when route cannot be resolved.
///
/// Args passed to this route: location: String
/// When returns null the current route will not change
typedef OnUnknownRoute = ActivityRoute? Function(RouteInformation request);

ActivityRoute? _defaultOnUnknownRoute(RouteInformation request) => null;

/// The returned widget must be or contains in its tree WidgetsApp
/// Use [MaterialApp.router] or [CupertinoApp.router] constructor and pass to it each of the provided parameters
typedef AppFactory = Widget Function(
  GlobalKey key,
  AppRouteInformationProvider routeInformationProvider,
  AppRouteInformationParser routeInformationParser,
  AppRouterDelegate routerDelegate,
  GenerateAppTitle onGenerateTitle,
  Locale? locale,
  Iterable<LocalizationsDelegate> localizationsDelegates,
  Iterable<Locale> supportedLocales,
);

Widget _defaultAppFactory(
  GlobalKey key,
  AppRouteInformationProvider routeInformationProvider,
  AppRouteInformationParser routeInformationParser,
  AppRouterDelegate routerDelegate,
  GenerateAppTitle onGenerateTitle,
  Locale? locale,
  Iterable<LocalizationsDelegate> localizationsDelegates,
  Iterable<Locale> supportedLocales,
) =>
    MaterialApp.router(
        key: key,
        routeInformationProvider: routeInformationProvider,
        routeInformationParser: routeInformationParser,
        routerDelegate: routerDelegate,
        onGenerateTitle: onGenerateTitle,
        locale: locale,
        localizationsDelegates: localizationsDelegates,
        supportedLocales: supportedLocales,
        debugShowCheckedModeBanner: false);

/// Factory for [SystemUiOverlayStyle] used by routes to define overlay style per page
typedef SystemUiStyleBuilder = SystemUiOverlayStyle Function(BuildContext context);

/// Default overlay style from appBarTheme and scaffoldBackgroundColor
SystemUiOverlayStyle defaultSystemUiStyle(BuildContext context) {
  final theme = Theme.of(context);
  final appBarTheme = theme.appBarTheme;
  final statusBarBrightness = appBarTheme.systemOverlayStyle?.statusBarBrightness ??
      appBarTheme.backgroundColor?.brightness ??
      theme.primaryColor.brightness;
  final navBarColor = theme.scaffoldBackgroundColor.darken(.05);
  return SystemUiOverlayStyle(
      systemNavigationBarColor: navBarColor,
      systemNavigationBarIconBrightness: navBarColor.brightness.negative,
      statusBarColor: Colors.black26,
      statusBarBrightness: statusBarBrightness,
      statusBarIconBrightness: appBarTheme.systemOverlayStyle?.statusBarIconBrightness ?? statusBarBrightness.negative);
}
